@@ -24,6 +24,7 @@ import org.snpeff.logStatsServer.VersionCheck;
 import org.snpeff.motif.Jaspar;
 import org.snpeff.motif.Pwm;
 import org.snpeff.pdb.DistanceResult;
+import org.snpeff.pdb.ProteinInteractions;
 import org.snpeff.serializer.MarkerSerializer;
 import org.snpeff.snpEffect.Config;
 import org.snpeff.snpEffect.ErrorWarningType;
@@ -93,10 +94,10 @@ public class SnpEff implements CommandLine {
 
 	// Version info
 	public static final String SOFTWARE_NAME = "SnpEff";
-	public static final String REVISION = "";
+	public static final String REVISION = "b";
 	public static final String BUILD = Gpr.compileTimeStamp(SnpEff.class);
 	public static final String BUILD_DATE = Gpr.compileDate(SnpEff.class);
-	public static final String VERSION_MAJOR = "5.1";
+	public static final String VERSION_MAJOR = "5.2";
 	public static final String VERSION_SHORT = VERSION_MAJOR + REVISION;
 	public static final String VERSION_BUILD = VERSION_SHORT + " (build " + BUILD + ")";
 	public static final String VERSION_AUTHOR = VERSION_BUILD + ", by " + Pcingola.BY;
@@ -142,6 +143,8 @@ public class SnpEff implements CommandLine {
 	protected String genomeVer; // Genome version
 	protected String onlyTranscriptsFile = null; // Only use the transcripts in this file (Format: One transcript ID per line)
 	protected String canonicalFile = null; // Use cannonical transcripts changing the ones that are present in the file.
+	protected Set<String> tags = new HashSet<>(); // Keep transcripts having these tags
+	protected Set<String> tagsNo = new HashSet<>(); // Remove transcripts having these tags
 	protected TranscriptSupportLevel maxTranscriptSupportLevel = null; // Filter by maximum Transcript Support Level (TSL)
 	protected StringBuilder output = new StringBuilder();
 	protected Config config; // Configuration
@@ -188,14 +191,19 @@ public class SnpEff implements CommandLine {
 		if (verbose) Log.info("Filtering out non-canonical transcripts.");
 		config.getSnpEffectPredictor().removeNonCanonical(canonicalFile);
 
+		// Show genes and transcript (which ones are considered 'canonical')
 		if (verbose) {
-			// Show genes and transcript (which ones are considered 'canonical')
-			Log.info("Canonical transcripts:\n\t\tgeneName\tgeneId\ttranscriptId\tcdsLength");
+			Log.info("Canonical transcripts:\n\t\tgeneName\tgeneId\ttranscriptId\tcdsLength\taaLength\tbioType\ttranscriptSupportLevel");
 			for (Gene g : config.getSnpEffectPredictor().getGenome().getGenes()) {
 				for (Transcript t : g) {
-					String cds = t.cds();
-					int cdsLen = (cds != null ? cds.length() : 0);
-					System.err.println("\t\t" + g.getGeneName() + "\t" + g.getId() + "\t" + t.getId() + "\t" + cdsLen);
+					System.err.println("\t\t" + g.getGeneName()
+							+ "\t" + g.getId()
+							+ "\t" + t.getId()
+							+ "\t" + (t.cds() != null ? t.cds().length() : 0)
+							+ "\t" + (t.protein() != null ? t.protein().length() : 0)
+							+ "\t" + t.getBioType()
+							+ "\t" + (t.getTranscriptSupportLevel() != null ? t.getTranscriptSupportLevel().toString() : "")
+					);
 				}
 			}
 		}
@@ -382,6 +390,18 @@ public class SnpEff implements CommandLine {
 		cmd.upDownStreamLength = upDownStreamLength;
 		cmd.verbose = verbose;
 		cmd.configOverride = configOverride;
+		cmd.tags = tags;
+		cmd.tagsNo = tagsNo;
+	}
+
+	/**
+	 * Filter by tags
+	 */
+	protected void filterTags() {
+		if( tags.isEmpty() && tagsNo.isEmpty() ) return;
+		if (verbose) Log.info("Filtering transcripts by tags " + tags + ", filter out tags " + tagsNo);
+		config.getSnpEffectPredictor().filterTags(tags, tagsNo);
+		if (verbose) Log.info("done.");
 	}
 
 	@Override
@@ -534,6 +554,9 @@ public class SnpEff implements CommandLine {
 		// Filter canonical transcripts
 		if (canonical || (canonicalFile != null && !canonicalFile.isEmpty())) canonical();
 
+		// Filter by tags
+		filterTags();
+
 		// Filter transcripts by TSL
 		if (maxTranscriptSupportLevel != null) {
 			if (verbose) Log.info("Filtering transcripts by Transcript Support Level (TSL): " + maxTranscriptSupportLevel);
@@ -618,7 +641,7 @@ public class SnpEff implements CommandLine {
 	 */
 	void loadInteractions() {
 		// Sanity checks
-		String intFileName = config.getDirDataGenomeVersion() + "/" + SnpEffCmdPdb.PROTEIN_INTERACTION_FILE;
+		String intFileName = config.getDirDataGenomeVersion() + "/" + ProteinInteractions.PROTEIN_INTERACTION_FILE;
 		if (!Gpr.exists(intFileName)) {
 			if (debug) if (!Gpr.exists(intFileName)) Log.warning(ErrorWarningType.WARNING_FILE_NOT_FOUND, "Cannot open interactions file '" + intFileName + "'");
 			return;
@@ -892,7 +915,6 @@ public class SnpEff implements CommandLine {
 			// These options are available for allow all commands
 			// Is it a command line option?
 			if (isOpt(arg)) {
-
 				switch (arg.toLowerCase()) {
 				case "-c":
 				case "-config":
@@ -1059,6 +1081,16 @@ public class SnpEff implements CommandLine {
 					strict = true;
 					break;
 
+				case "-tag":
+					if ((i + 1) < args.length) tags.add(args[++i]); // Add this tag to the list
+					else usage("Option '-tag' without tagName argument");
+					break;
+
+				case "-tagno":
+					if ((i + 1) < args.length) tagsNo.add(args[++i]); // Add this tag to the list
+					else usage("Option '-tagNo' without tagName argument");
+					break;
+
 				//				case "-t":
 				//					multiThreaded = true;
 				//					break;
@@ -1278,7 +1310,9 @@ public class SnpEff implements CommandLine {
 		System.err.println("\nDatabase options:");
 		System.err.println("\t-canon                       : Only use canonical transcripts.");
 		System.err.println("\t-canonList <file>            : Only use canonical transcripts, replace some transcripts using the 'gene_id \t transcript_id' entries in <file>.");
-		System.err.println("\t-interaction                 : Annotate using inteactions (requires interaciton database). Default: " + interaction);
+		System.err.println("\t-tag <tagName>               : Only use transcript having a tag 'tagName'. This option can be used multiple times.");
+		System.err.println("\t-notag <tagName>             : Filter out transcript having a tag 'tagName'. This option can be used multiple times.");
+		System.err.println("\t-interaction                 : Annotate using interactions (requires interaction database). Default: " + interaction);
 		System.err.println("\t-interval <file>             : Use a custom intervals in TXT/BED/BigBed/VCF/GFF file (you may use this option many times)");
 		System.err.println("\t-maxTSL <TSL_number>         : Only use transcripts having Transcript Support Level lower than <TSL_number>.");
 		System.err.println("\t-motif                       : Annotate using motifs (requires Motif database). Default: " + motif);
